@@ -29,6 +29,12 @@ main (int argc, char **argv)
   struct msv_response *response;
 
   ctx = msv_ctxt_init (NULL);
+  if (!ctx) {
+      printf ("Unable to initialize context\n"
+              "Make sure MONKEYSPHERE_VALIDATION_AGENT_SOCKET env variable is set and\n"
+              "the MSVA validation agent is running\n");
+      exit (1);
+  }
 
   x = msv_check_msva (ctx);
   printf ("MSVA check: %s\n", msv_strerror (ctx, x));
@@ -66,6 +72,10 @@ main (int argc, char **argv)
     "xHMcOGjzfj0LUSqVEVe/D8VzeTEQiNs1MVuRtpQ/dciEL2dkXqjzZiuuhs6TIvDG\n"
     "6wknKthAJdFSXGQkb7kGiw==\n" "-----END CERTIFICATE-----\n";
   x = msv_query_agent (ctx, query, &response);
+  if (!response) {
+      printf ("MSV query: failure contacting MSV agent\n");
+      exit (2);
+  }
   printf ("MSV query: %s\nValid: %s\nMessage: %s\n", msv_strerror (ctx, x),
 	  response->valid ? "true" : "false", response->message);
 
